# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import thumbnail_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2


class ThumbnailServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.BatchGenerateDownloadURLs = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
                )
        self.GenerateUploadURL = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
                )


class ThumbnailServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def List(self, request, context):
        """List thumbnails for channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Create thumbnail.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGenerateDownloadURLs(self, request, context):
        """Generate urls for download images.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateUploadURL(self, request, context):
        """Generate url for upload image.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ThumbnailServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchGenerateDownloadURLs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGenerateDownloadURLs,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.SerializeToString,
            ),
            'GenerateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateUploadURL,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.ThumbnailService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ThumbnailService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGenerateDownloadURLs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
