# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.billing.v1 import billing_account_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2
from yandex.cloud.billing.v1 import billing_account_service_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class BillingAccountServiceStub(object):
    """A set of methods for managing BillingAccount resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/Get',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/List',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.FromString,
                )
        self.ListBillableObjectBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/ListBillableObjectBindings',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.FromString,
                )
        self.BindBillableObject = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/BindBillableObject',
                request_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.billing.v1.BillingAccountService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class BillingAccountServiceServicer(object):
    """A set of methods for managing BillingAccount resources.
    """

    def Get(self, request, context):
        """Returns the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of billing accounts available for current user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBillableObjectBindings(self, request, context):
        """Retrieves the list of billable object bindings associated with the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BindBillableObject(self, request, context):
        """Binds billable object to the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists access bindings for the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified billing account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BillingAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.SerializeToString,
            ),
            'ListBillableObjectBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBillableObjectBindings,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.SerializeToString,
            ),
            'BindBillableObject': grpc.unary_unary_rpc_method_handler(
                    servicer.BindBillableObject,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.billing.v1.BillingAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BillingAccountService(object):
    """A set of methods for managing BillingAccount resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/Get',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.GetBillingAccountRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/List',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillingAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBillableObjectBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/ListBillableObjectBindings',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.ListBillableObjectBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BindBillableObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/BindBillableObject',
            yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__service__pb2.BindBillableObjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.billing.v1.BillingAccountService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
